@@ -1,9 +1,13 @@
 import inspect
 from abc import abstractmethod
-from typing import Any, Callable, Dict, Iterable, Mapping, Sequence, cast
+from typing import Any, Callable, Dict, Iterable, Mapping, Sequence, cast, List
 
 from argo_workflow_tools.dsl import building_mode_context as context
-from argo_workflow_tools.dsl.dag_task import DAGReference, TaskReference, WorkflowTemplateReference
+from argo_workflow_tools.dsl.dag_task import (
+    DAGReference,
+    TaskReference,
+    WorkflowTemplateReference,
+)
 from argo_workflow_tools.dsl.input_definition import InputDefinition, SourceType
 from argo_workflow_tools.dsl.node_properties.dag_node_properties import (
     DAGNodeProperties,
@@ -71,7 +75,7 @@ class Node(object):
         return filtered_kwargs
 
     @staticmethod
-    def _get_wait(kwargs) -> list["str"]:
+    def _get_wait(kwargs) -> List["str"]:
         """
         Generaete dependecy out of wait_for parameter
         Parameters
@@ -87,7 +91,7 @@ class Node(object):
             return []
         dependencies = cast(InputDefinition, kwargs.get("wait_for"))
         if (
-                isinstance(dependencies, InputDefinition) and dependencies.is_node_output
+            isinstance(dependencies, InputDefinition) and dependencies.is_node_output
         ):  # TODO or it's variants NODE_OUTPUT
             return [dependencies]
         if isinstance(dependencies, Iterable):
@@ -101,11 +105,11 @@ class Node(object):
     @staticmethod
     def _reduce_fan_in_arguments(name: str, arg: Any) -> Any:
         if (
-                isinstance(arg, Sequence)
-                and len(arg) == 1
-                and isinstance(arg[0], InputDefinition)
-                and arg[0].is_node_output
-                and arg[0].reference
+            isinstance(arg, Sequence)
+            and len(arg) == 1
+            and isinstance(arg[0], InputDefinition)
+            and arg[0].is_node_output
+            and arg[0].reference
         ):
             return InputDefinition(
                 SourceType.REDUCE,
@@ -114,7 +118,11 @@ class Node(object):
                 references=arg[0],
             )
 
-        if not isinstance(arg, str) and isinstance(arg, Sequence) and any([item.is_node_output for item in arg]):
+        if (
+            not isinstance(arg, str)
+            and isinstance(arg, Sequence)
+            and any([item.is_node_output for item in arg])
+        ):
             raise ValueError(
                 f"Argument '{name}' of type '{type(arg).__name__}' is invalid. it mixes both parameters and node outputs"
             )
@@ -149,14 +157,15 @@ class Node(object):
     def _get_arg(argument_name: str, argument_value: Any) -> InputDefinition:
         if isinstance(argument_value, InputDefinition):
             return argument_value
-        return InputDefinition(source_type=SourceType.CONST, value=argument_value ,name=argument_name)
+        return InputDefinition(
+            source_type=SourceType.CONST, value=argument_value, name=argument_name
+        )
 
     @staticmethod
     def _arguments(arguments: Mapping[str, Any]) -> Mapping[str, InputDefinition]:
         return {
             argument_name: Node._get_arg(argument_name, argument_value)
             for argument_name, argument_value in arguments.items()
-
         }
 
 
@@ -197,15 +206,17 @@ class DAGNode(Node):
             )
 
         if len(self.properties.outputs.items()) == 0:
-            outputs = {"result": InputDefinition(
-                source_type=SourceType.NODE_OUTPUT,
-                source_node_id=guid,
-                name=sanitize_name("result"),
-                references=partitioned_arguments,
-                parameter_builder=self.properties.outputs.get(
-                    "result", DefaultParameterBuilder(None)
-                ),
-            )}
+            outputs = {
+                "result": InputDefinition(
+                    source_type=SourceType.NODE_OUTPUT,
+                    source_node_id=guid,
+                    name=sanitize_name("result"),
+                    references=partitioned_arguments,
+                    parameter_builder=self.properties.outputs.get(
+                        "result", DefaultParameterBuilder(None)
+                    ),
+                )
+            }
         else:
             outputs = {
                 name: InputDefinition(
@@ -213,7 +224,7 @@ class DAGNode(Node):
                     source_node_id=guid,
                     name=sanitize_name(name),
                     references=partitioned_arguments,
-                    parameter_builder=parameter_builder
+                    parameter_builder=parameter_builder,
                 )
                 for name, parameter_builder in self.properties.outputs.items()
             }
@@ -277,15 +288,17 @@ class TaskNode(Node):
             condition.condition_string() for condition in collect_conditions()
         ]
         if len(self.properties.outputs.items()) == 0:
-            outputs = {"result": InputDefinition(
-                source_type=SourceType.NODE_OUTPUT,
-                source_node_id=guid,
-                name=sanitize_name("result"),
-                references=partitioned_arguments,
-                parameter_builder=self.properties.outputs.get(
-                    "result", DefaultParameterBuilder(None)
-                ),
-            )}
+            outputs = {
+                "result": InputDefinition(
+                    source_type=SourceType.NODE_OUTPUT,
+                    source_node_id=guid,
+                    name=sanitize_name("result"),
+                    references=partitioned_arguments,
+                    parameter_builder=self.properties.outputs.get(
+                        "result", DefaultParameterBuilder(None)
+                    ),
+                )
+            }
         else:
             outputs = {
                 name: InputDefinition(
@@ -293,7 +306,7 @@ class TaskNode(Node):
                     source_node_id=guid,
                     name=sanitize_name(name),
                     references=partitioned_arguments,
-                    parameter_builder=parameter_builder
+                    parameter_builder=parameter_builder,
                 )
                 for name, parameter_builder in self.properties.outputs.items()
             }
@@ -346,7 +359,11 @@ class WorkflowTemplateNode(DAGNode):
 
         arguments = self._bind_arguments(*args, **kwargs)
         partitioned_arguments = list(
-            filter(lambda argument: isinstance(argument, InputDefinition) and argument.is_partition, arguments.values())
+            filter(
+                lambda argument: isinstance(argument, InputDefinition)
+                and argument.is_partition,
+                arguments.values(),
+            )
         )
         if len(partitioned_arguments) > 1:
             raise ValueError(
@@ -354,15 +371,17 @@ class WorkflowTemplateNode(DAGNode):
             )
 
         if len(self.properties.outputs.items()) == 0:
-            outputs = {"result": InputDefinition(
-                source_type=SourceType.NODE_OUTPUT,
-                source_node_id=guid,
-                name=sanitize_name("result"),
-                references=partitioned_arguments,
-                parameter_builder=self.properties.outputs.get(
-                    "result", DefaultParameterBuilder(None)
-                ),
-            )}
+            outputs = {
+                "result": InputDefinition(
+                    source_type=SourceType.NODE_OUTPUT,
+                    source_node_id=guid,
+                    name=sanitize_name("result"),
+                    references=partitioned_arguments,
+                    parameter_builder=self.properties.outputs.get(
+                        "result", DefaultParameterBuilder(None)
+                    ),
+                )
+            }
         else:
             outputs = {
                 name: InputDefinition(
@@ -370,7 +389,7 @@ class WorkflowTemplateNode(DAGNode):
                     source_node_id=guid,
                     name=sanitize_name(name),
                     references=partitioned_arguments,
-                    parameter_builder=parameter_builder
+                    parameter_builder=parameter_builder,
                 )
                 for name, parameter_builder in self.properties.outputs.items()
             }
