@@ -1,4 +1,5 @@
-from typing import Union,List,Dict,Tuple
+from typing import Union, List, Dict, Tuple
+import json
 
 import shortuuid
 from argo_workflow_tools.models.io.argoproj.workflow import v1alpha1 as argo
@@ -25,7 +26,7 @@ def delete_none(_dict: dict) -> dict:
 
 def _convert_params(
     args: Union[Dict[str, str], List[Union[argo.Arguments, argo.Parameter]]]
-) -> tuple[List[argo.Artifact], List[argo.Parameter]]:
+) -> Tuple[List[argo.Artifact], List[argo.Parameter]]:
     if isinstance(args, dict):
         parameters = [
             argo.Parameter(name=sanitize_name(key), value=value)
@@ -72,5 +73,15 @@ def sanitize_name(name: str) -> str:
     return name.replace("_", "-")
 
 
+def convert_str(value: any) -> str:
+    if value is None:
+        return None
+    if value is bool:
+        return str(value).lower()
+    if value is str:
+        return value
+    return json.dumps(value)
+
+
 def uuid_short():
     return shortuuid.random(5)
